Learn R Programming

RImagePalette (version 0.1.0)

image_pal: Image palette

Description

Image palette function

Usage

image_pal(image, choice = mean, volume = FALSE)

Arguments

image
Matrix The image from which the palette will be extracted from. Should be a 3 (or more) dimensional matrix. The output of a function such as readJPG() or readPNG() are suitable as image.
choice
Function Defines how the color will be chosen from the final color cubes. The default choice is to take the mean value of the image cube, but other choices may return a subjectively superior scale. Try median, or min
volume
Logical volume controls the method for choosing which color cube to split at each iteration of the algorithm. The default choice (when volume = FALSE) is to choose the cube based on which cube contains the largest extent (that is, the largest

Examples

Run this code
img <- jpeg::readJPEG(system.file("img", "Rlogo.jpg", package="jpeg"))
display_image(img)
scales::show_col(image_pal(img)(10))

Run the code above in your browser using DataLab