image_palette(image, n, choice = mean, volume = FALSE)
Arguments
image
Matrix The image from which the palette will be extracted from. Should
be a 3 (or more) dimensional matrix. The output of a function such as readJPG()
or readPNG() are suitable as image.
n
Integer The number of discrete colors to be extracted from the image.
choice
Function Defines how the color will be chosen from the final color cubes.
The default choice is to take the mean value of the image cube, but other choices
may return a subjectively superior scale. Try median, or min
volume
Logical volume controls the method for choosing which color cube to split
at each iteration of the algorithm. The default choice (when volume = FALSE) is to
choose the cube based on which cube contains the largest extent (that is, the largest
Details
Uses the median cut algorithm to create n discrete colors based on colors
present in an image. See median_cut for more details.