choice
Function Defines how the color will be chosen from the final color cubes.
The default choice is to take the mean value of the image cube, but other choices
may return a subjectively superior scale. Try median, or min
volume
Logical volume controls the method for choosing which color cube to split
at each iteration of the algorithm. The default choice (when volume = FALSE) is to
choose the cube based on which cube contains the largest extent (that is, the largest